@@ -1,6 +1,8 @@
-draw.levset<-function(pcf,lev,bary=NULL)
+draw.levset<-function(pcf,lev=NULL,bary=NULL,propor=0.1)
 {
 
+if (is.null(lev)) lev<-propor*max(pcf$value)
+
 d<-length(pcf$N)
 step<-matrix(0,d,1)
 for (i in 1:d) step[i]=(pcf$support[2*i]-pcf$support[2*i-1])/pcf$N[i];
