@@ -1,7 +1,7 @@
-eva.gauss<-function(x,t=1,marginal="unif",sig=c(1,1),r=0)
-# 
-#  sig is std of marginals
+eva.gauss<-function(x,t=1,marginal="unif",sig=c(1,1),r=0,tapa1=TRUE)
 {
+#  sig is std of marginals
+
 if (marginal=="unif"){
    u<-x[1]/sig[1]+1/2
    v<-x[2]/sig[2]+1/2
@@ -24,13 +24,20 @@ if (marginal=="student"){
 d<-2
 x1<-qnorm(u,sd=1)
 x2<-qnorm(v,sd=1)
-produ<-dnorm(x1,sd=1)*dnorm(x2,sd=1)
 
-nelio<-(x1^2+x2^2-2*r*x1*x2)/(1-r^2)
-vakio<-(2*pi)^(-d/2) 
-g<-vakio*(1-r^2)^(-1/2)*exp(-(1/2)*nelio)
-
-val<-g/produ*marg1*marg2
+if (tapa1){
+  produ<-dnorm(x1,sd=1)*dnorm(x2,sd=1)
+  nelio<-(x1^2+x2^2-2*r*x1*x2)/(1-r^2)
+  vakio<-(2*pi)^(-d/2) 
+  g<-vakio*(1-r^2)^(-1/2)*exp(-(1/2)*nelio)
+  val<-g/produ*marg1*marg2
+}
+else{
+  # x1,x2 -> copuval
+  copuval<-(1-r^2)^(-1/2)*
+  exp(-(x1^2+x2^2-2*r*x1*x2)/(2*(1-r^2)))/exp(-(x1^2+x2^2)/2)
+  val<-copuval*marg1*marg2
+}
 
 return(val)
 }
